@@ -1,6 +1,6 @@
 """Api client module."""
 from datetime import datetime
-from typing import Any, Union
+from typing import Any
 from urllib.parse import urljoin
 
 from ._api_client import _InternalApiClient
@@ -57,8 +57,10 @@ class ApiClient:
                 else:
                     _LOGGER.debug("Skipping device as it is not supported: %s", device)
             return devices
-        _LOGGER.error("Failed to get devices")
-        raise ApiError(f"failure {resp['error']} ({resp['errno']}) on getting devices")
+        _LOGGER.error("Failed to get devices: %s", resp)
+        raise ApiError(
+            f"failure {resp.get('error', '')} ({resp.get('errno', '')}) on getting devices"
+        )
 
     async def get_product_iot_map(self) -> dict[str, Any]:
         """Get product iot map."""
@@ -80,7 +82,7 @@ class ApiClient:
 
     async def send_command(
         self,
-        command: Union[Command, CustomCommand],
+        command: Command | CustomCommand,
         device_info: DeviceInfo,
     ) -> dict[str, Any]:
         """Send json command for given vacuum to the api."""
