@@ -1,7 +1,8 @@
 """Base commands."""
 from abc import ABC, abstractmethod
+from collections.abc import Mapping
 from dataclasses import dataclass
-from typing import Any, Mapping, final
+from typing import Any, final
 
 from ..command import Command
 from ..events import EnableEvent
@@ -157,7 +158,7 @@ class _GetEnableCommand(_NoArgsCommand):
     # required as name is class variable, will be overwritten in subclasses
     name = "__invalid__"
 
-    @classmethod
+    @classmethod  # type: ignore[misc]
     @property
     @abstractmethod
     def event_type(cls) -> type[EnableEvent]:
