@@ -1,5 +1,6 @@
 """(fan) speed commands."""
-from typing import Any, Mapping
+from collections.abc import Mapping
+from typing import Any
 
 from ..events import FanSpeedEvent
 from ..message import HandlingResult
