@@ -31,6 +31,7 @@ class BatteryEvent(Event):
 class CleanJobStatus(DisplayNameIntEnum):
     """Enum of the different clean job status."""
 
+    NO_STATUS = -2
     CLEANING = -1
     # below the identified stop_reason values
     FINISHED = 1
@@ -57,6 +58,13 @@ class CleanLogEvent(Event):
     logs: list[CleanLogEntry]
 
 
+@dataclass(frozen=True)
+class CleanCountEvent(Event):
+    """Clean count event representation."""
+
+    count: int
+
+
 @dataclass(frozen=True)
 class CustomCommandEvent(Event):
     """Custom command event representation."""
@@ -120,7 +128,7 @@ class ReportStatsEvent(StatsEvent):
 
     cleaning_id: str
     status: CleanJobStatus
-    content: list[int] | None
+    content: list[int]
 
 
 @dataclass(frozen=True)
@@ -168,3 +176,18 @@ class ContinuousCleaningEvent(EnableEvent):
 @dataclass(frozen=True)
 class CarpetAutoFanBoostEvent(EnableEvent):
     """Carpet pressure event."""
+
+
+@dataclass(frozen=True)
+class CleanPreferenceEvent(EnableEvent):
+    """CleanPreference event."""
+
+
+@dataclass(frozen=True)
+class MultimapStateEvent(EnableEvent):
+    """Multimap state event."""
+
+
+@dataclass(frozen=True)
+class TrueDetectEvent(EnableEvent):
+    """TrueDetect event."""
